Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(175)

Unified Diff: net/ftp/ftp_server_type_histograms.h

Issue 384007: Distinguish between old and new FTP LIST response parsers (Closed)
Patch Set: eroman's suggestion Created 11 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/ftp/ftp_directory_listing_parsers.h ('k') | webkit/glue/ftp_directory_listing_response_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ftp/ftp_server_type_histograms.h
diff --git a/net/ftp/ftp_server_type_histograms.h b/net/ftp/ftp_server_type_histograms.h
index 08ca4240c562aec940be4b89621bd80aad4f1c5b..fef9bb2b94134a3fe982a22c03c45973e600792e 100644
--- a/net/ftp/ftp_server_type_histograms.h
+++ b/net/ftp/ftp_server_type_histograms.h
@@ -19,14 +19,22 @@ enum FtpServerType {
// connecting to isn't an FTP server), or a broken server.
SERVER_UNKNOWN = 0,
- SERVER_LSL = 1, // Server using /bin/ls -l and variants.
- SERVER_DLS = 2, // Server using /bin/dls.
- SERVER_EPLF = 3, // Server using EPLF format.
- SERVER_DOS = 4, // WinNT server configured for old style listing.
- SERVER_VMS = 5, // VMS (including variants).
- SERVER_CMS = 6, // IBM VM/CMS, VM/ESA, z/VM formats.
- SERVER_OS2 = 7, // OS/2 FTP Server.
- SERVER_W16 = 8, // win16 hosts: SuperTCP or NetManage Chameleon.
+ // The types below are recognized by ParseFTPList code from Mozilla. If we hit
+ // one of these, it means that our new LIST parser failed for that server.
+ SERVER_MOZ_LSL = 1, // Server using /bin/ls -l and variants.
+ SERVER_MOZ_DLS = 2, // Server using /bin/dls.
+ SERVER_MOZ_EPLF = 3, // Server using EPLF format.
+ SERVER_MOZ_DOS = 4, // WinNT server configured for old style listing.
+ SERVER_MOZ_VMS = 5, // VMS (including variants).
+ SERVER_MOZ_CMS = 6, // IBM VM/CMS, VM/ESA, z/VM formats.
+ SERVER_MOZ_OS2 = 7, // OS/2 FTP Server.
+ SERVER_MOZ_W16 = 8, // win16 hosts: SuperTCP or NetManage Chameleon.
+
+ // The types below are recognized by our new LIST parser. If we hit one of
+ // these, it means that it's working quite well.
+ SERVER_LS = 9, // Server using /bin/ls -l listing style.
+ SERVER_WINDOWS = 10, // Server using Windows listing style.
+ SERVER_VMS = 11, // Server using VMS listing style.
NUM_OF_SERVER_TYPES
};
« no previous file with comments | « net/ftp/ftp_directory_listing_parsers.h ('k') | webkit/glue/ftp_directory_listing_response_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698